# Get Config SUT MLPerf Inference
This [CM script](https://github.com/mlcommons/ck/blob/master/cm/docs/specs/script.md) loads the MLPerf inference performance configuration of a given System Under Test (SUT).

## Supported and Tested OS
1. Ubuntu 18.04, 20.04, 22.04
2. RHEL 9
